/*
  Test coverage tool.

   Copyright (C) 2012 Red Hat

This tool is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This tool is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this tool; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/



/*
 * Script used to filter methods in a report generated for each API class and
 * also for given package or set of packages.
 *
 * @author Pavel Tisnovsky <ptisnovs@redhat.com>
 */



/*
 * Set display style for selected CSS class.
 */
function setDisplayStyle(selectorText, displayStyle)
{
    // array containing all CSS rules
    var setOfCssRules = new Array();
    // acquire the array depending on browser capabilities
    if (document.styleSheets[0].cssRules)
    {
        setOfCssRules = document.styleSheets[0].cssRules;
    }
    else if (document.styleSheets[0].rules)
    {
        setOfCssRules = document.styleSheets[0].rules;
    }
    // iterate through all rules
    for (i in setOfCssRules)
    {
        // and select display style for selected rules
        if (setOfCssRules[i].selectorText == selectorText)
        {
            setOfCssRules[i].style.display = displayStyle;
        }
    }
}

/*
 * Show all methods - table containing methods coveraged by test
 * and also methods which are not coveraged.
 */
function showAll()
{
    setDisplayStyle(".coveraged", "");
}

/*
 * Show only methods not coveraged by test.
 */
function showDiff(selectorText)
{
    setDisplayStyle(".coveraged", "none");
}

/*
 * Show only classes with the test coverage which is less or
 * equal than given threshold (%).
 */
function showPercent(threshold)
{
    var percent;
    for (percent = 0; percent <= 100; percent += 10)
    {
        // construct CSS class name
        // it should look like as follows:
        // ".coverage_0", ".coverage_10", ... ".coverage_100"
        var cssClassName = ".coverage_" + percent;

        //window.alert(cssClassName);

        // when percent is lower than threshold
        // then rows with such % should be displayed
        if (percent <= threshold)
        {
            setDisplayStyle(cssClassName, "");
        }
        // otherwise the rows should be unvisible
        else
        {
            setDisplayStyle(cssClassName, "none");
        }
    }
}

